import {request} from '../utils/request.js'
function doctorList(data){ //创建问诊订单
  return request('/patient/doctor/inquiry','GET',data,true)
};
function doctorDetail(data){ //获取问诊医生详情
  return request('/doctor/info/inquiry/'+data,'GET',data,true)
};
function doctorService(data){ //获取医生开启的服务列表
    return request('/doctor/inquiry/service/'+data,'GET',data,true)
  };
function getEvaluation(id,data){ //获取医生评价
  return request('/patient/doctor/evaluation/'+id,'GET',data)
};
function getConsultTime(data){ //获取系统问诊时间
  return request('/system/inquiry/time','GET',data)
};
function isReceivepatient(data){ //检测是否可以接诊
  return request('/patient/inquiry/check','GET',data)
};
function lastSick(id){ //获取家庭成员病例数据
  return request('/patient/family/case/'+id,'GET')
};
function getProvince(data){ //获取省份
  return request('/area/province','GET',data)
};
function getCity(data){ //获取城市
  return request('/area/city','GET',data)
};
function getCountry(data){ //获取区县信息
  return request('/area/county','GET',data)
};
function commentList(data){
  return request('/evaluation','GET',data,true)
 
}
function fllowDoctor(id){
  return request('/patient/doctor/follow/'+id,'POST')
}
function notfllowDoctor(id){
  return request('/patient/doctor/follow/'+id,'DELETE')
}
function getService(id){//获取医生开启的服务列表
    return request('/doctor/inquiry/service/'+id,'GET')
  }

module.exports={
  doctorList,
  doctorDetail,
  doctorService,
  getConsultTime,
  isReceivepatient,
  getEvaluation,
  lastSick,
  getProvince,
  getCity,
  getCountry,
  commentList,
  fllowDoctor,
  notfllowDoctor,
  getService


}